@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: shakespeare
-version: 2.0.8
-id: shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
-key: shake_1vghqhLLSePE0tznKG19vt
+version: 2.0.8.2
+id: shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
+key: shake_JiUTC8JfMMi93OhWtxHxIf
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -30,15 +30,15 @@ exposed-modules:
 hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                 Text.IndentToBrace Text.CssCommon
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8
-library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8
-data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.8
-hs-libraries: HSshakespeare-2.0.8-1vghqhLLSePE0tznKG19vt
+import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.8.2
+hs-libraries: HSshakespeare-2.0.8.2-JiUTC8JfMMi93OhWtxHxIf
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
